### Name: affinity
### Title: Chemical Affinities of Formation Reactions
### Aliases: affinity energy energy.args
### Keywords: misc

### ** Examples

  ## Don't show: 
data(thermo)
## End Don't show

  ## set up a system and calculate
  ## chemical affinities of formation reactions
  basis(c("SiO2","MgO","H2O","O2"),c(-5,-5,0,999))
  species(c("quartz","enstatite","forsterite"))
  # chemical affinities (A/2.303RT) at 25 deg C and 1 bar
  affinity()
  # at higher temperature and pressure
  affinity(T=500,P=2000)
  # ten different temperatures at one pressure
  affinity(T=c(500,1000,10),P=2000)
  # at 25 temperatures and pressures
  affinity(T=c(500,1000,5),P=c(1000,5000,5))
  # as a function of logarithm of activity of MgO
  affinity(MgO=c(-10,-5,10))
  ## equilibrium constants of formation reactions
  affinity(property="logK")
  # Standard molal Gibbs energies of species,
  # user units (default: cal/mol)
  affinity(property="G.species")
  # Standard molal Gibbs energies of reactions
  affinity(property="G")

  ### these examples can be run using longex("afffinity")
  ## Not run: 
##D     ## Activity of glycine as a function of those of
##D     ## HCN and formaldehyde (200 C, 300 bar)
##D     ## After Schulte and Shock, 1995, Fig. 5
##D     # we can define the basis as this:
##D     basis(c("formaldehyde","H2O","HCN","O2"))
##D     species("glycine")
##D     a <- affinity(HCHO=c(-10,-2,9),HCN=c(-18,-2,9),T=200,P=300)
##D     # that gave us *affinities* (dimensionless) for logact(glycine)=-3
##D     # (the default). we can now find the *activities* that
##D     # correspond to affinity=0
##D     logact.glycine <- species()$logact + a$values[[1]]
##D     # note transposition of the z-value matrix in the following command
##D     contour(x=-10:-2,y=seq(-18,-2,by=2),z=t(logact.glycine),
##D       xlab=axis.label("HCHO"),ylab=axis.label("HCN"),
##D       labcex=1,xaxs="i",yaxs="i")
##D     title(main=paste("log activity glycine, after Schulte and Shock, 1995",
##D       "200 deg C, 300 bar, logaH2O = 1",sep="\n"))
##D 
##D     ## amino acid synthesis at low and high temperatures
##D     ## after Amend and Shock, 1998
##D     # select the basis species and species of interest
##D     # and set their activities (first for the 18 degree C case)
##D     basis(c("H2O","CO2","NH4+","H2","H+","H2S"),
##D       log10(c(1,1e-4,5e-8,2e-9,5e-9,1e-15)))
##D     species(c("alanine","argininate","asparagine","aspartate","cysteine",
##D       "glutamate","glutamine","glycine","histidine","isoleucine",
##D       "leucine","lysinium","methionine","phenylalanine","proline",
##D       "serine","threonine","tryptophan","tyrosine","valine"),
##D       log10(c(3.9,0.7,1.1,3.3,0.5,3.8,1.0,5.8,1.2,0.7,
##D       0.8,1.0,2.8,0.5,0.5,4.6,5.8,0.6,0.9,2.8)/1e9))
##D     Tc <- 18
##D     T <- convert(Tc,"K")
##D     # converting A (dimensionless) to G of reaction (cal/mol) 
##D     # is like converting log K to standard G of reaction 
##D     AS98.18 <- 
##D       convert(convert(as.numeric(affinity(T=Tc)$values),"G",T=T),"J")/1000
##D     # the 100 degree C case
##D     Tc <- 100
##D     T <- convert(Tc,"K")
##D     basis(c("H2O","CO2","NH4+","H2","H+","H2S"),
##D       log10(c(1,2.2e-3,2.9e-6,3.4e-4,1.9e-6,1.6e-3)))
##D     species(1:20,log10(c(2.8e-9,5.0e-10,7.9e-10,2.4e-9,3.6e-10,
##D                          2.7e-9,7.2e-10,4.2e-9,8.6e-10,5.0e-10,
##D                          5.7e-10,7.2e-10,2.0e-9,3.6e-10,3.6e-10,
##D                          3.3e-9,4.2e-9,4.3e-10,6.5e-10,2.0e-9)))
##D     AS98.100 <- 
##D       convert(convert(as.numeric(affinity(T=Tc)$values),"G",T=T),"J")/1000
##D     # the nominal carbon oxidation state
##D     Z.C <- ZC(as.character(thermo$obigt$formula[thermo$species$ispecies]))
##D     # put them together
##D     print(data.frame(T100=AS98.100,T18=AS98.18,Z.C=Z.C))
##D     # values not exactly reproducing AS98 - different amino acid parameters
##D     # forget species to run next example
##D     species(delete=TRUE)
##D 
##D     ## affinities of metabolic reactions
##D     ## after Amend and Shock, 2001, Fig. 7
##D     basis(c("CO2","H2","NH3","O2","H2S","H+"))
##D     basis(c("O2","H2"),"aq")   # O2 and H2 were gas
##D     species("H2O")
##D     doplot <- function(T) {
##D       res <- 20
##D       a <- affinity(H2=c(-10,0,res),O2=c(-10,0,res),T=T)
##D       T.K <- convert(T,"K")   # temperature in Kelvin
##D       a <- convert(a$values[[1]],"G",T.K)  # affinities (cal/mol)
##D       a <- convert(a,"J")  # affinities (Joule)
##D       contour(x=seq(-10,0,length.out=res),
##D         y=seq(-10,0,length.out=res),z=t(a/1000),
##D         labcex=1,xlab=axis.label("H2"),ylab=axis.label("O2"))
##D     }
##D     layout(matrix(c(1,1,2,3,4,5),ncol=2,byrow=TRUE),heights=c(1,4,4))
##D     T <- c(25,55,100,150)
##D     par(mar=c(0,0,0,0))
##D     plot.new()
##D     text(0.5,0.1,paste(c("H2(aq) + 0.5O2(aq) = H2O(liq)\n\n",
##D       "after Amend and Shock, 2001")),cex=2)
##D     par(mar=c(3,3,0.5,0.5),cex=1.3,mgp=c(2,1,0))
##D     for(i in 1:length(T)) doplot(T[i])
##D     # this is so the plots in the next examples show up OK
##D     layout(matrix(1))
##D 
##D     ## continuation of last example, affinity calculations 
##D     ## in three dimensions
##D     print(affinity(H2=c(-10,0,3),O2=c(-10,0,3),T=c(25,150,4))$values)
##D 
##D     ## calculations on a transect
##D     # suppose that temperature and oxygen fugacity
##D     # both change in space (say from 1 to 6 meters),
##D     # that we have six values for each but want to
##D     # interpolate them to make a plot with smooth curves
##D     T <- splinefun(1:6,c(0,25,30,40,55,75))(seq(1,5,length.out=100))
##D     O2 <- splinefun(1:6,c(-90,-83,-78,-73,-68,-63))(seq(1,5,length.out=100))
##D     # what system could this be? 
##D     basis("CHNOS+")
##D     species(paste("CSG",c("METBU","METVO","METTL","METJA"),sep="_"))
##D     # now pass T and O2 to affinity, which because their lengths
##D     # are greater than three, treats them like coordinates for a
##D     # transect through chemical potential space rather than
##D     # the definition of a 2-dimensional grid
##D     a <- affinity(T=T,O2=O2)
##D     diagram(a,ylim=c(-4,-2))
##D     title(main=paste("Computed abundances of surface-layer proteins",
##D       "as a function of T and logfO2",sep="\n"))
##D   
## End(Not run)
  



