### Name: basis
### Title: Basis Species
### Aliases: basis
### Keywords: misc

### ** Examples

  ## Don't show: 
data(thermo)
## End Don't show
  ## define basis species
  basis("O2")  # one element
  basis(c("H2O","O2"))  # two elements
  basis(c("H2O","O2","H+"))

  ## Not run: 
##D     # marked dontrun because they produce intentional errors
##D     # fewer basis species than elements
##D     basis(c("H2O","H+"))
##D     # more basis species than elements
##D     basis(c("H2O","O2","H2","H+"))
##D     # non-independent basis species
##D     basis(c("CO2","H2O","HCl","Cl-","H+"))
##D   
## End(Not run)

  ## specify activities and states
  basis(c("H2O","O2","CO2"),c(-2,-78,-3),c("liq","gas","aq"))
  # change logarithms of activities/fugacities  
  basis(c("H2O","O2"),c(0,-80)) 
  # change state of CO2
  basis("CO2","gas")

  ## get the basis stoichiometry of species
  basis("CHNOS")                        
  ispecies <- info(c("glutamic acid","phenylalanine"))
  basis(ispecies)
                        
  ## changing the basis species
  basis("CHNOPS+")
  # load species whose names are like "ATP"
  species(info("ATP ")[[1]])
  # notice missing elements; try a new basis
  basis("MgCHNOPS+")  # species are deleted
  species(info("ATP ")[[1]])
  # different basis species, but same elements
  basis(c("MgSO4","HCHO","CH4","NO","CO","H3PO4","CS2","OH-"))
  species()  # formation reactions were updated



