### Name: thermo
### Title: Thermodynamic Properties and Compositional Data
### Aliases: thermo OBIGT proteins opt source stress PM90 RH95 RT71 SGD ECO
###   groups
### Keywords: datasets

### ** Examples

  ## Don't show: 
data(thermo)
## End Don't show
  ## exploring thermo$obigt
  # what physical states there are
  unique(thermo$obigt$state)
  # formulas of ten random species
  n <- nrow(thermo$obigt)
  thermo$obigt$formula[runif(10)*n]

  ## cross-checking sources
  # the reference sources
  ref.source <- thermo$source$source
  # only take those that aren't journal abbreviations
  ref.source <- ref.source[-grep('_',ref.source)]
  # sources of elemental data
  element.source <- thermo$element$source
  # primary sources in thermodynamic database
  obigt.source1 <- thermo$obigt$source1
  # secondary sources; some are NA
  obigt.source2 <- 
    thermo$obigt$source2[!is.na(thermo$obigt$source2)]
  # sources of protein compositions
  protein.source <- thermo$protein$source
  # sources of stress response proteins
  stress.source <- as.character(thermo$stress[2,])
  # if the sources are all accounted for 
  # these all produce character(0)
  element.source[!(element.source %in% ref.source)]
  obigt.source1[!(obigt.source1 %in% ref.source)]
  obigt.source2[!(obigt.source2 %in% ref.source)]
  protein.source[!(protein.source %in% ref.source)]
  stress.source[!(stress.source %in% ref.source)]
  # determine if all the reference sources are cited
  my.source <- c(element.source,obigt.source1,
    obigt.source2,protein.source,stress.source)
  # this should produce character(0)
  ref.source[!(ref.source %in% my.source)]

  ## make a table of duplicated species
  name <- thermo$obigt$name
  state <- thermo$obigt$state
  source <- thermo$obigt$source1
  species <- paste(name,state)
  dups <- species[which(duplicated(species))]
  id <- numeric()
  for(i in 1:length(dups)) id <- c(id,which(species %in% dups[i]))
  data.frame(name=name[id],state=state[id],source=source[id])

  ## accessing duplicated species
  # using info()
  i <- info("Al+3","aq")  # length = 2
  i1 <- info("Al+3")      # length = 1
  stopifnot(i1==i[1])
  thermo$opt$level <- 2
  i2 <- info("Al+3")      # length = 1
  stopifnot(i2==i[2])
  # using subcrt()
  subcrt("Al+3","aq")  # always uses the first species
  subcrt("Al+3")  # pays attention to thermo$opt$level
  # .. showing the energetic differences between the
  # duplicated species
  subcrt(i,c(-1,1))
  # using basis()
  basis(c("Al+3","H+","H2"))  
  thermo$opt$level <- 1
  basis(c("Al+3","H+","H2"))  
  # using species()
  species("Al+3","aq")  # listens to thermo$opt$level
  thermo$opt$level <- 2
  species("Al+3")  # also listens to thermo$opt$level
  species(delete=TRUE)
  species(rev(i)) # can also use the species indices
  # see also aluminum speciation example in diagram() help page



