### Name: eos
### Title: Equations of State
### Aliases: hkf cgl
### Keywords: misc

### ** Examples

  ## Don't show: 
data(thermo)
## End Don't show
  
  ## aqueous species
  a <- info(info("methane","aq"))       
  hkf(property="Cp",ghs=a,eos=a)
  # the non-solvation heat capacity
  hkf(property="Cp",ghs=a,eos=a,contrib="n")    
  # at different temperature and pressure
  hkf(property="Cp",ghs=a,eos=a,T=c(373.15,473.15),P=1000)
  
  ## crystalline, gas, liquid species
  a <- info(info("methane","gas"))      
  cgl(property="Cp",ghs=a,eos=a)
  # melting and vaporization of n-octane
  a <- info(info(rep("n-octane",3),c("cr","liq","gas")))
  t <- cgl(property="G",ghs=a,eos=a,T=seq(200,420,10),P=1)
  which.pmax(t,pmin=TRUE)  # 1 = cr, 2 = liq, 3 = gas
  # compare that result with the tabulated 
  # transition temperatures
  print(a)




