### Name: revisit
### Title: Diversity Calculations for Chemical Species
### Aliases: revisit richness extremes where.extreme draw.diversity
### Keywords: misc

### ** Examples

  ## Don't show: 
data(thermo)
## End Don't show
  ### these examples can be run using longex("revisit")
  ## Not run: 
##D     ## carboxylases from different organisms
##D     # ribulose phosphate carboxylase/oxygenase
##D     rubisco <- c("Q6JAI0_9RHOD","A5CKC7_9CHRO","RBL_SYNJA","A1E8R4_9CHLO",
##D       "A8C9T6_9MYCO","A3EQE1_9BACT","A6YF84_9PROT", "RBL_BRAJA",
##D       "A1RZJ5_THEPD","RBL_METJA","A3DND9_STAMF","RBL_PYRHO") 
##D     # acetyl-coenzyme A carboxylase
##D     accoaco <- c("Q05KD0_HYDTH","Q9F7M8_PRB01","A6CDM2_9PLAN","A0GZU2_9CHLR",
##D       "ACCA_DEIRA","A1VC70_DESVV","A7WGI1_9AQUI","Q2JSS7_SYNJA",
##D       "A4AGS7_9ACTN","ACCA_AQUAE","ACCA_CAUCR","A6VIX9_METM7")  
##D     # calculate affinities as a function of T with
##D     # buffered logfH2 and CO2.. adjust the glutathione buffer 
##D     # (more oxidizing than default)
##D     mod.buffer("GSH-GSSG",c("GSH","GSSG"),logact=c(-3,-7))
##D     # add a CO2 gas saturation buffer
##D     mod.buffer("CO2","CO2","gas",-1)
##D     basis(c("CO2","H2O","NH4+","SO4-2","H2","H+"),
##D       c("CO2",0,-4,-4,"GSH-GSSG",-7))
##D     species(c(rubisco,accoaco))
##D     a <- affinity(T=c(0,160))
##D     # create speciation diagram with colors
##D     col <- c(rep("red",12),rep("blue",12))
##D     d <- diagram(a,residue=TRUE,color=col,ylim=c(-6,-1),legend.x=NULL)
##D     legend("topleft",col=c("red","blue"),lty=1,
##D       legend=c("ribulose phosphate carboxylase",
##D       "acetyl-coenzyme A carboxylase"))
##D     title(main=paste("Calculated relative abundances of",
##D       "carboxylases from different organisms",sep="\n"))
##D     # ... now on to a species richness diagram
##D     # all the proteins, then rubisco and accoaco
##D     draw.diversity(d,"richness",logactmin=-3.6)
##D     draw.diversity(d,"richness",logactmin=-3.6,
##D       ispecies=1:12,col="red",add=TRUE)
##D     draw.diversity(d,"richness",logactmin=-3.6,
##D       ispecies=13:24,col="blue",add=TRUE)
##D     legend("bottomleft",col=c("red","blue","black"),lty=1,
##D       legend=c("ribulose phosphate carboxylase",
##D       "acetyl-coenzyme A carboxylase","all"))
##D     title(main=paste("Carboxylases with activities",
##D       "greater than 10^(-3.6)",sep="\n"))
##D 
##D     ## continuing from above ... make a rank-abundance
##D     ## diagram and fit with a lognormal distribution
##D     if(require(vegan)) {
##D       basis("H2",-4)
##D       a <- affinity()
##D       logact <- diagram(a,residue=TRUE,do.plot=FALSE)$logact
##D       act <- 10^as.numeric(logact)
##D       # we use family=Gamma because our species have activities
##D       # (i.e., proportional abundances) and not integer counts
##D       mod <- rad.lognormal(act,family=Gamma)
##D       plot(mod,main=paste("Relative abundances of carboxylases",
##D         "fit with lognormal distribution",sep="\n"))
##D       # calculate Shannon diversity index
##D       # using revisit (CHNOSZ)
##D       H1 <- revisit(act,"shannon",as.is=TRUE)
##D       legend("topright",legend=paste("H =",round(H1,2)),pch=1)
##D       # using diversity (vegan)
##D       H2 <- diversity(matrix(act,nrow=1))
##D       stopifnot(isTRUE(all.equal(H1,H2)))
##D     }
##D 
##D     ### using grep.file, read.fasta, add.protein
##D     # calculations for Pelagibacter ubique
##D     f <- system.file("HTCC1062.faa",package="CHNOSZ")
##D     # line numbers of all entries in the file
##D     j <- grep.file(f)  # length = 1354
##D     # locate entries whose names contain DNA
##D     j <- grep.file(f,"hypothetical")
##D     # get the amino acid compositions of these protein
##D     p <- read.fasta(f,j)
##D     # add these proteins to CHNOSZ's inventory
##D     i <- add.protein(p)
##D     # set up a thermodynamic system
##D     basis("CHNOS+")
##D     # calculate affinities in logfO2-pH space
##D     a <- affinity(H2O=c(-10,-2),O2=c(-82,-76),iprotein=i)
##D     # calculate the logarithms of activities
##D     d <- diagram(a,do.plot=FALSE,mam=FALSE)
##D     # show the protein richness
##D     draw.diversity(d,"richness",logactmin="")
##D     mtitle(c("Richness of hypothetical proteins in",
##D       expression(italic("Pelagibacter ubique"))))
##D     # show the coefficient of variation of activities
##D     draw.diversity(d,"cv")
##D     mtitle(c("Coefficient of variation of hypothetical",
##D       expression("protein activities in"~italic("P. ubique"))))
##D   
## End(Not run)



